@@ -8,11 +8,13 @@ the machinery in this module will notice that we have no identification
 credentials yet and that the server accepts registration messages, so it
 will craft an appropriate one and send it out.
 """
+import json
 import logging
 
 from twisted.internet.defer import Deferred
 
 from landscape.client.broker.exchange import maybe_bytes
+from landscape.client.manager.ubuntuproinfo import get_ubuntu_pro_info
 from landscape.lib.juju import get_juju_info
 from landscape.lib.network import get_fqdn
 from landscape.lib.tag import is_valid_tag_list
@@ -56,6 +58,8 @@ class Identity:
     @ivar secure_id: A server-provided ID for secure message exchange.
     @ivar insecure_id: Non-secure server-provided ID, mainly used with
         the ping server.
+    @ivar accepted_types: The types of messages the server will accept
+        from the client during exchange
     @ivar computer_title: See L{BrokerConfiguration}.
     @ivar account_name: See L{BrokerConfiguration}.
     @ivar registration_password: See L{BrokerConfiguration}.
@@ -75,6 +79,7 @@ class Identity:
     tags = config_property("tags")
     access_group = config_property("access_group")
     hostagent_uid = config_property("hostagent_uid")
+    installation_request_id = config_property("installation_request_id")
 
     def __init__(self, config, persist):
         self._config = config
@@ -190,6 +195,7 @@ class RegistrationHandler:
         group = identity.access_group
         registration_key = identity.registration_key
         hostagent_uid = identity.hostagent_uid
+        installation_request_id = identity.installation_request_id
 
         self._message_store.delete_all_messages()
 
@@ -219,6 +225,8 @@ class RegistrationHandler:
             message["access_group"] = group
         if hostagent_uid:
             message["hostagent_uid"] = hostagent_uid
+        if installation_request_id:
+            message["installation_request_id"] = installation_request_id
 
         server_api = self._message_store.get_server_api()
         # If we have juju data to send and if the server is recent enough to
@@ -239,6 +247,8 @@ class RegistrationHandler:
         with_tags = f"and tags {tags} " if tags else ""
         with_group = f"in access group '{group}' " if group else ""
 
+        message["ubuntu_pro_info"] = json.dumps(get_ubuntu_pro_info())
+
         logging.info(
             f"Queueing message to register with account {account_name!r} "
             f"{with_group}{with_tags}{with_word} a password.",
