@@ -66,8 +66,8 @@ class HTTPTransportTest(LandscapeTest):
             transport.exchange,
             payload,
             computer_id="34",
-            exchange_token="abcd-efgh",
-            message_api="X.Y",
+            exchange_token=b"abcd-efgh",
+            message_api=b"X.Y",
         )
 
         def got_result(ignored):
@@ -141,7 +141,7 @@ class HTTPTransportTest(LandscapeTest):
             transport.exchange,
             "HI",
             computer_id="34",
-            message_api="X.Y",
+            message_api=b"X.Y",
         )
 
         def got_result(ignored):
@@ -190,19 +190,13 @@ class HTTPTransportTest(LandscapeTest):
             transport.exchange,
             "HI",
             computer_id="34",
-            message_api="X.Y",
+            message_api=b"X.Y",
         )
 
-        def got_result(ignored):
+        def got_result(failure):
             self.assertIs(r.request, None)
             self.assertIs(r.content, None)
-            logfile_value = self.logfile.getvalue()
-            # pycurl error messages vary by version.
-            # First is for <= noble, second for > noble.
-            self.assertTrue(
-                "server certificate verification failed" in logfile_value
-                or "SSL certificate problem" in logfile_value,
-            )
+            self.assertEqual(failure.value.error_code, 60)
 
         result.addErrback(got_result)
         return result
