@@ -3,16 +3,20 @@ import os.path
 import subprocess
 import sys
 import time
+from argparse import SUPPRESS
 from datetime import datetime
 from datetime import timezone
 from logging import debug
-from optparse import SUPPRESS_HELP
+from logging import info
+from typing import Sequence
 
 from twisted.logger import globalLogBeginner
 
 from landscape import VERSION
 from landscape.client import DEFAULT_CONFIG
+from landscape.client import GROUP
 from landscape.client import snap_http
+from landscape.client import USER
 from landscape.client.snap_utils import get_snap_info
 from landscape.client.upgraders import UPGRADE_MANAGERS
 from landscape.lib import logging
@@ -51,7 +55,7 @@ class BaseConfiguration(_BaseConfiguration):
 
     default_config_filename = DEFAULT_CONFIG
     if _is_script():
-        default_config_filenames = (
+        default_config_filenames: Sequence[str] = (
             "landscape-client.conf",
             default_config_filename,
         )
@@ -69,7 +73,7 @@ class BaseConfiguration(_BaseConfiguration):
     def make_parser(self):
         """Parser factory for supported options.
 
-        @return: An OptionParser preset with options that all
+        @return: An ArgumentParser preset with options that all
             programs commonly accept. These include
               - config
               - data_path
@@ -91,7 +95,7 @@ class Configuration(BaseConfiguration):
     def make_parser(self):
         """Parser factory for supported options.
 
-        @return: An L{OptionParser} preset for all options
+        @return: An L{ArgumentParser} preset for all options
             from L{BaseConfiguration.make_parser} plus:
               - C{quiet} (C{False})
               - C{log_dir} (C{"/var/log/landscape"})
@@ -104,57 +108,57 @@ class Configuration(BaseConfiguration):
         """
         parser = super().make_parser()
         logging.add_cli_options(parser, logdir="/var/log/landscape")
-        parser.add_option(
+        parser.add_argument(
             "-u",
             "--url",
             default=self.DEFAULT_URL,
             help="The server URL to connect to.",
         )
-        parser.add_option(
+        parser.add_argument(
             "--ping-url",
             help="The URL to perform lightweight exchange initiation with.",
             default="http://landscape.canonical.com/ping",
         )
-        parser.add_option(
+        parser.add_argument(
             "-k",
             "--ssl-public-key",
             help="The public SSL key to verify the server. "
             "Only used if the given URL is https.",
         )
-        parser.add_option(
+        parser.add_argument(
             "--ignore-sigint",
             action="store_true",
             default=False,
             help="Ignore interrupt signals.",
         )
-        parser.add_option(
+        parser.add_argument(
             "--ignore-sigusr1",
             action="store_true",
             default=False,
             help="Ignore SIGUSR1 signal to " "rotate logs.",
         )
-        parser.add_option(
+        parser.add_argument(
             "--package-monitor-interval",
             default=30 * 60,
-            type="int",
+            type=int,
             help="The interval between package monitor runs "
             "(default: 1800).",
         )
-        parser.add_option(
+        parser.add_argument(
             "--apt-update-interval",
             default=6 * 60 * 60,
-            type="int",
+            type=int,
             help="The interval between apt update runs (default: 21600).",
         )
-        parser.add_option(
+        parser.add_argument(
             "--flush-interval",
             default=5 * 60,
-            type="int",
+            type=int,
             metavar="INTERVAL",
             help="The number of seconds between flushes to disk "
             "for persistent data.",
         )
-        parser.add_option(
+        parser.add_argument(
             "--stagger-launch",
             metavar="STAGGER_RATIO",
             dest="stagger_launch",
@@ -163,20 +167,20 @@ class Configuration(BaseConfiguration):
             help="Ratio, between 0 and 1, by which to stagger "
             "various tasks of landscape.",
         )
-        parser.add_option(
+        parser.add_argument(
             "--snap-monitor-interval",
             default=30 * 60,
-            type="int",
+            type=int,
             help="The interval between snap monitor runs (default 1800).",
         )
 
         # Hidden options, used for load-testing to run in-process clones
-        parser.add_option("--clones", default=0, type=int, help=SUPPRESS_HELP)
-        parser.add_option(
+        parser.add_argument("--clones", default=0, type=int, help=SUPPRESS)
+        parser.add_argument(
             "--start-clones-over",
             default=25 * 60,
             type=int,
-            help=SUPPRESS_HELP,
+            help=SUPPRESS,
         )
 
         return parser
@@ -238,7 +242,11 @@ def get_versioned_persist(service):
     Load a L{Persist} database for the given C{service} and upgrade or
     mark as current, as necessary.
     """
-    persist = Persist(filename=service.persist_filename)
+    persist = Persist(
+        filename=service.persist_filename,
+        user=USER,
+        group=GROUP,
+    )
     upgrade_manager = UPGRADE_MANAGERS[service.service_name]
     if os.path.exists(service.persist_filename):
         upgrade_manager.apply(persist)
@@ -297,3 +305,23 @@ def generate_computer_title(auto_enroll_config):
         title = hostname
 
     return title
+
+
+def convert_arg_to_bool(value: str) -> bool:
+    """
+    Converts an argument provided that is in string format
+    to be a boolean value.
+    """
+    TRUTHY_VALUES = {"true", "yes", "y", "1", "on"}
+    FALSY_VALUES = {"false", "no", "n", "0", "off"}
+
+    if value.lower() in TRUTHY_VALUES:
+        return True
+    elif value.lower() in FALSY_VALUES:
+        return False
+    else:
+        info(
+            "Error. Invalid boolean provided in config or parameters. "
+            + "Defaulting to False.",
+        )
+        return False
