@@ -1,12 +1,14 @@
-import os
 import logging
+import os
 
-from landscape.lib.compat import _PY3
-
-from landscape.lib.compat import ConfigParser, NoOptionError
+from landscape.client import GROUP
+from landscape.client import USER
 from landscape.client.monitor.plugin import DataWatcher
-from landscape.lib.persist import Persist
+from landscape.lib.compat import _PY3
+from landscape.lib.compat import ConfigParser
+from landscape.lib.compat import NoOptionError
 from landscape.lib.fs import read_binary_file
+from landscape.lib.persist import Persist
 
 
 KEYSTONE_CONFIG_FILE = "/etc/keystone/keystone.conf"
@@ -17,6 +19,7 @@ class KeystoneToken(DataWatcher):
     A plugin which pulls the admin_token from the keystone configuration file
     and sends it to the landscape server.
     """
+
     message_type = "keystone-token"
     message_key = "data"
     run_interval = 60 * 15
@@ -26,12 +29,20 @@ class KeystoneToken(DataWatcher):
         self._keystone_config_file = keystone_config_file
 
     def register(self, client):
-        super(KeystoneToken, self).register(client)
-        self._persist_filename = os.path.join(self.registry.config.data_path,
-                                              "keystone.bpickle")
-        self._persist = Persist(filename=self._persist_filename)
-        self.registry.reactor.call_every(self.registry.config.flush_interval,
-                                         self.flush)
+        super().register(client)
+        self._persist_filename = os.path.join(
+            self.registry.config.data_path,
+            "keystone.bpickle",
+        )
+        self._persist = Persist(
+            filename=self._persist_filename,
+            user=USER,
+            group=GROUP,
+        )
+        self.registry.reactor.call_every(
+            self.registry.config.flush_interval,
+            self.flush,
+        )
 
     def _reset(self):
         """
@@ -54,16 +65,20 @@ class KeystoneToken(DataWatcher):
             # We need to use the surrogateescape error handler as the
             # admin_token my contain arbitrary bytes. The ConfigParser in
             # Python 2 on the other hand does not support read_string.
-            config_str = read_binary_file(
-                self._keystone_config_file).decode("utf-8", "surrogateescape")
+            config_str = read_binary_file(self._keystone_config_file).decode(
+                "utf-8",
+                "surrogateescape",
+            )
             config.read_string(config_str)
         else:
             config.read(self._keystone_config_file)
         try:
             admin_token = config.get("DEFAULT", "admin_token")
         except NoOptionError:
-            logging.error("KeystoneToken: No admin_token found in %s"
-                          % (self._keystone_config_file))
+            logging.error(
+                "KeystoneToken: No admin_token found in "
+                f"{self._keystone_config_file}",
+            )
             return None
         # There is no support for surrogateescape in Python 2, but we actually
         # have bytes in this case anyway.
