@@ -1,3 +1,5 @@
+import logging
+
 from twisted.python.reflect import namedClass
 
 from landscape.client.amp import ComponentPublisher
@@ -28,13 +30,26 @@ class ManagerService(LandscapeService):
 
     def get_plugins(self):
         """Return instances of all the plugins enabled in the configuration."""
-        return [
-            namedClass(
-                "landscape.client.manager."
-                f"{plugin_name.lower()}.{plugin_name}",
-            )()
-            for plugin_name in self.config.plugin_factories
-        ]
+        plugins = []
+
+        for plugin_name in self.config.plugin_factories:
+            try:
+                plugin = namedClass(
+                    "landscape.client.manager."
+                    f"{plugin_name.lower()}.{plugin_name}",
+                )
+                plugins.append(plugin())
+            except ModuleNotFoundError:
+                logging.warning(
+                    f"Invalid manager plugin specified: '{plugin_name}'"
+                    "See `example.conf` for a full list of monitor plugins.",
+                )
+            except Exception as exc:
+                logging.warning(
+                    f"Unable to load manager plugin '{plugin_name}': {exc}",
+                )
+
+        return plugins
 
     def startService(self):  # noqa: N802
         """Start the manager service.
