@@ -1,3 +1,5 @@
+from unittest import mock
+
 from landscape.client.manager.config import ALL_PLUGINS
 from landscape.client.manager.config import ManagerConfiguration
 from landscape.client.manager.processkiller import ProcessKiller
@@ -11,22 +13,31 @@ class ManagerServiceTest(LandscapeTest):
 
     helpers = [FakeBrokerServiceHelper]
 
+    class FakeManagerService(ManagerService):
+        reactor_factory = FakeReactor
+
     def setUp(self):
         super().setUp()
         config = ManagerConfiguration()
         config.load(["-c", self.config_filename])
 
-        class FakeManagerService(ManagerService):
-            reactor_factory = FakeReactor
+        self.service = self.FakeManagerService(config)
 
-        self.service = FakeManagerService(config)
-
-    def test_plugins(self):
+    @mock.patch("dbus.SystemBus")
+    def test_plugins(self, system_bus_mock):
         """
         By default the L{ManagerService.plugins} list holds an instance of
         every enabled manager plugin.
+
+        We mock `dbus` because in some build environments that run these tests,
+        such as buildd, SystemBus is not available.
         """
-        self.assertEqual(len(self.service.plugins), len(ALL_PLUGINS))
+        config = ManagerConfiguration()
+        config.load(["-c", self.config_filename])
+        service = self.FakeManagerService(config)
+
+        self.assertEqual(len(service.plugins), len(ALL_PLUGINS))
+        system_bus_mock.assert_called_once_with()
 
     def test_get_plugins(self):
         """
@@ -37,6 +48,34 @@ class ManagerServiceTest(LandscapeTest):
         [plugin] = self.service.get_plugins()
         self.assertTrue(isinstance(plugin, ProcessKiller))
 
+    def test_get_plugins_module_not_found(self):
+        """If a module is not found, a warning is logged."""
+        self.service.config.load(["--manager-plugins", "TotallyDoesNotExist"])
+
+        with self.assertLogs(level="WARN") as cm:
+            plugins = self.service.get_plugins()
+
+        self.assertEqual(len(plugins), 0)
+        self.assertIn("Invalid manager plugin", cm.output[0])
+        self.assertIn("TotallyDoesNotExist", cm.output[0])
+
+    def test_get_plugins_other_exception(self):
+        """If loading a plugin fails for another reason, a warning is logged,
+        with the exception.
+        """
+        self.service.config.load(["--manager-plugins", "ProcessKiller"])
+
+        with self.assertLogs(level="WARN") as cm:
+            with mock.patch(
+                "landscape.client.manager.service.namedClass",
+            ) as namedClass:
+                namedClass.side_effect = Exception("Is there life on Mars?")
+                plugins = self.service.get_plugins()
+
+        self.assertEqual(len(plugins), 0)
+        self.assertIn("Unable to load", cm.output[0])
+        self.assertIn("Mars?", cm.output[0])
+
     def test_start_service(self):
         """
         The L{ManagerService.startService} method connects to the broker,
