@@ -1,19 +1,23 @@
+import json
+import os
+import tempfile
 from datetime import datetime
 from unittest import mock
 
 from landscape.client.manager.ubuntuproinfo import get_ubuntu_pro_info
 from landscape.client.manager.ubuntuproinfo import UbuntuProInfo
 from landscape.client.tests.helpers import LandscapeTest
-from landscape.client.tests.helpers import MonitorHelper
+from landscape.client.tests.helpers import ManagerHelper
 
 
 class UbuntuProInfoTest(LandscapeTest):
     """Ubuntu Pro info plugin tests."""
 
-    helpers = [MonitorHelper]
+    helpers = [ManagerHelper]
 
     def setUp(self):
         super().setUp()
+        self.mstore = self.broker_service.message_store
         self.mstore.set_accepted_types(["ubuntu-pro-info"])
 
     def test_ubuntu_pro_info(self):
@@ -24,7 +28,7 @@ class UbuntuProInfoTest(LandscapeTest):
             run_mock.return_value = mock.Mock(
                 stdout='"This is a test"',
             )
-            self.monitor.add(plugin)
+            self.manager.add(plugin)
             plugin.run()
 
         run_mock.assert_called()
@@ -36,7 +40,7 @@ class UbuntuProInfoTest(LandscapeTest):
     def test_ubuntu_pro_info_no_pro(self):
         """Tests calling `pro status` when it is not installed."""
         plugin = UbuntuProInfo()
-        self.monitor.add(plugin)
+        self.manager.add(plugin)
 
         with mock.patch("subprocess.run") as run_mock:
             run_mock.side_effect = FileNotFoundError()
@@ -75,7 +79,7 @@ class UbuntuProInfoTest(LandscapeTest):
     def test_persistence_unchanged_data(self):
         """If data hasn't changed, a new message is not sent"""
         plugin = UbuntuProInfo()
-        self.monitor.add(plugin)
+        self.manager.add(plugin)
         data = '"Initial data!"'
 
         with mock.patch("subprocess.run") as run_mock:
@@ -103,7 +107,7 @@ class UbuntuProInfoTest(LandscapeTest):
     def test_persistence_changed_data(self):
         """New data will be sent in a new message in the queue"""
         plugin = UbuntuProInfo()
-        self.monitor.add(plugin)
+        self.manager.add(plugin)
 
         with mock.patch("subprocess.run") as run_mock:
             run_mock.return_value = mock.Mock(
@@ -132,7 +136,7 @@ class UbuntuProInfoTest(LandscapeTest):
         """Resetting the plugin will allow a message with identical data to
         be sent"""
         plugin = UbuntuProInfo()
-        self.monitor.add(plugin)
+        self.manager.add(plugin)
         data = '"Initial data!"'
 
         with mock.patch("subprocess.run") as run_mock:
@@ -161,14 +165,40 @@ class UbuntuProInfoTest(LandscapeTest):
         self.assertTrue("ubuntu-pro-info" in messages[1])
         self.assertEqual(messages[1]["ubuntu-pro-info"], data)
 
-    @mock.patch("landscape.client.manager.ubuntuproinfo.IS_SNAP", new=True)
-    def test_pro_client_not_called_for_snap(self):
-        """
-        The snap will not currently allow calls to the pro client.
+    @mock.patch.multiple(
+        "landscape.client.manager.ubuntuproinfo",
+        IS_SNAP=True,
+        UA_DATA_DIR=tempfile.gettempdir(),
+    )
+    def test_pro_status_file_read_for_snap(self):
+        """The snap should read the status file instead of calling `pro`."""
+        temp_file_path = os.path.join(tempfile.gettempdir(), "status.json")
+        with open(temp_file_path, "w") as fp:
+            mocked_info = {
+                "_schema_version": "0.1",
+                "account": {
+                    "created_at": "2024-01-08T13:26:52+00:00",
+                    "external_account_ids": [],
+                    "id": "zYxWvU_sRqPoNmLkJiHgFeDcBa9876543210ZyXwVuTsRqPon",
+                    "name": "jane.doe@example.com",
+                },
+                "foo": "bar"
+            }
+            json.dump(mocked_info, fp)
 
-        Ensure that get_ubuntu_pro_info returns an empty dictionary instead of
-        calling the subprocess for pro.
-        """
+        ubuntu_pro_info = get_ubuntu_pro_info()
+        del mocked_info["foo"]
+        self.assertEqual(mocked_info, ubuntu_pro_info)
+
+        os.remove(temp_file_path)
+
+    @mock.patch.multiple(
+        "landscape.client.manager.ubuntuproinfo",
+        IS_SNAP=True,
+        UA_DATA_DIR="/i/do/not/exist",
+    )
+    def test_pro_status_file_not_found_for_snap(self):
+        """The snap will return {} if the status file is not found."""
         ubuntu_pro_info = get_ubuntu_pro_info()
         self.assertEqual({}, ubuntu_pro_info)
 
