@@ -3,15 +3,14 @@ import subprocess
 from datetime import datetime
 from datetime import timedelta
 from datetime import timezone
-from pathlib import Path
 
 from landscape.client import IS_CORE
 from landscape.client import IS_SNAP
-from landscape.client.manager.plugin import ManagerPlugin
-from landscape.lib.persist import Persist
+from landscape.client.manager.plugin import DataWatcherManager
+from landscape.client import UA_DATA_DIR
 
 
-class UbuntuProInfo(ManagerPlugin):
+class UbuntuProInfo(DataWatcherManager):
     """
     Plugin that captures and reports Ubuntu Pro registration
     information.
@@ -25,41 +24,10 @@ class UbuntuProInfo(ManagerPlugin):
     message_type = "ubuntu-pro-info"
     run_interval = 900  # 15 minutes
 
-    def register(self, registry):
-        super().register(registry)
-        self._persist_filename = Path(
-            self.registry.config.data_path,
-            "ubuntu-pro-info.bpickle",
-        )
-        self._persist = Persist(filename=self._persist_filename)
-        self.call_on_accepted(self.message_type, self.send_message)
-
-    def run(self):
-        return self.registry.broker.call_if_accepted(
-            self.message_type,
-            self.send_message,
-        )
-
-    def send_message(self):
-        """Send a message to the broker if the data has changed since the last
-        call"""
-        result = self.get_data()
-        if not result:
-            return
-        message = {"type": self.message_type, "ubuntu-pro-info": result}
-        return self.registry.broker.send_message(message, self._session_id)
-
     def get_data(self):
-        """Persist data to avoid sending messages if result hasn't changed"""
         ubuntu_pro_info = get_ubuntu_pro_info()
-
-        if self._persist.get("data") != ubuntu_pro_info:
-            self._persist.set("data", ubuntu_pro_info)
-            return json.dumps(ubuntu_pro_info, separators=(",", ":"))
-
-    def _reset(self):
-        """Reset the persist."""
-        self._persist.remove("data")
+        return json.dumps(ubuntu_pro_info, separators=(",", ":"),
+                          sort_keys=True)
 
 
 def get_ubuntu_pro_info() -> dict:
@@ -80,9 +48,47 @@ def get_ubuntu_pro_info() -> dict:
         )
 
     if IS_SNAP:
-        # Snap does not support Ubuntu Pro Info and throws an error if `pro` is
-        # called.
-        return {}
+        # By default, Ubuntu Advantage / Pro stores the status information
+        # in /var/lib/ubuntu-advantage/status.json (we have a `system-files`
+        # plug for this).
+        # This `data_dir` can however be changed in
+        # /etc/ubuntu-advantage/uaclient.conf which would lead to
+        # permission errors since we don't have a plug for arbitrary
+        # folders on the host fs.
+
+        try:
+            with open(f"{UA_DATA_DIR}/status.json") as fp:
+                pro_info = json.load(fp)
+        except (FileNotFoundError, PermissionError):
+            # Happens if the Ubuntu Pro client isn't installed, or
+            #  if the `data_dir` folder setting was changed from the default
+            return {}
+
+        # The status file has more information than `pro status`
+        keys_to_keep = [
+            "_doc",
+            "_schema_version",
+            "account",
+            "attached",
+            "config",
+            "config_path",
+            "contract",
+            "effective",
+            "environment_vars",
+            "errors",
+            "execution_details",
+            "execution_status",
+            "expires",
+            "features",
+            "machine_id",
+            "notices",
+            "result",
+            "services",
+            "simulated",
+            "version",
+            "warnings",
+        ]
+        return {k: pro_info[k] for k in keys_to_keep if k in pro_info}
 
     try:
         completed_process = subprocess.run(
