@@ -20,9 +20,8 @@ ALL_PLUGINS = [
     "SwiftUsage",
     "CephUsage",
     "ComputerTags",
-    "LivePatch",
-    "UbuntuProRebootRequired",
     "SnapServicesMonitor",
+    "CloudInit",
 ]
 
 
@@ -36,7 +35,7 @@ class MonitorConfiguration(Configuration):
         """
         parser = super().make_parser()
 
-        parser.add_option(
+        parser.add_argument(
             "--monitor-plugins",
             metavar="PLUGIN_LIST",
             help="Comma-delimited list of monitor plugins to "
