@@ -1,4 +1,3 @@
-import locale
 import logging
 import os
 import shutil
@@ -1187,7 +1186,9 @@ class PackageReporterAptTest(LandscapeTest):
         release_path = os.path.join(self.repository_dir, "Release")
         with open(release_path, "w") as release:
             release.write(
-                "Suite: {}-security".format(os_release_info["code-name"]),
+                f"Suite: {os_release_info['code-name']}-security\n"
+                "Date: Sat, 02 Jul 2016 05:20:50 +0000\n"
+                "MD5Sum: deadbeef"
             )
 
         self.store.set_hash_ids({HASH1: 1, HASH2: 2, HASH3: 3})
@@ -1246,7 +1247,9 @@ class PackageReporterAptTest(LandscapeTest):
         release_path = os.path.join(self.repository_dir, "Release")
         with open(release_path, "w") as release:
             release.write(
-                "Suite: {}-backports".format(os_release_info["code-name"]),
+                f"Suite: {os_release_info['code-name']}-backports\n"
+                "Date: Sat, 02 Jul 2016 05:20:50 +0000\n"
+                "MD5Sum: deadbeef"
             )
 
         self.store.set_hash_ids({HASH1: 1, HASH2: 2, HASH3: 3})
@@ -1269,7 +1272,11 @@ class PackageReporterAptTest(LandscapeTest):
 
         release_path = os.path.join(self.repository_dir, "Release")
         with open(release_path, "w") as release:
-            release.write("Suite: my-personal-backports")
+            release.write(
+                "Suite: my-personal-backports"
+                "Date: Sat, 02 Jul 2016 05:20:50 +0000\n"
+                "MD5Sum: deadbeef"
+            )
 
         self.store.set_hash_ids({HASH1: 1, HASH2: 2, HASH3: 3})
 
@@ -1306,11 +1313,17 @@ class PackageReporterAptTest(LandscapeTest):
         official_release_path = os.path.join(self.repository_dir, "Release")
         with open(official_release_path, "w") as release:
             release.write(
-                "Suite: {}-backports".format(os_release_info["code-name"]),
+                f"Suite: {os_release_info['code-name']}-backports\n"
+                "Date: Sat, 02 Jul 2016 05:20:50 +0000\n"
+                "MD5Sum: deadbeef"
             )
         unofficial_release_path = os.path.join(other_backport_dir, "Release")
         with open(unofficial_release_path, "w") as release:
-            release.write("Suite: my-personal-backports")
+            release.write(
+                "Suite: my-personal-backports\n"
+                "Date: Sat, 02 Jul 2016 05:20:50 +0000\n"
+                "MD5Sum: deadbeef"
+            )
 
         self.store.set_hash_ids({HASH1: 1, HASH2: 2, HASH3: 3})
 
@@ -1443,34 +1456,6 @@ class PackageReporterAptTest(LandscapeTest):
             self.assertEqual("RESULT", main(["ARGS"]))
         m.assert_called_once_with(PackageReporter, ["ARGS"])
 
-    def test_main_resets_locale(self):
-        """
-        Reporter entry point should reset encoding to utf-8, as libapt-pkg
-        encodes description with system encoding and python-apt decodes
-        them as utf-8 (LP: #1827857).
-        """
-        self._add_package_to_deb_dir(
-            self.repository_dir,
-            "gosa",
-            description="GOsa\u00B2",
-        )
-        self.facade.reload_channels()
-
-        # Set the only non-utf8 locale which we're sure exists.
-        # It behaves slightly differently than the bug, but fails on the
-        # same condition.
-        locale.setlocale(locale.LC_CTYPE, (None, None))
-        self.addCleanup(locale.resetlocale)
-
-        with mock.patch("landscape.client.package.reporter.run_task_handler"):
-            main([])
-
-        # With the actual package, the failure will occur looking up the
-        # description translation.
-        pkg = self.facade.get_packages_by_name("gosa")[0]
-        skel = self.facade.get_package_skeleton(pkg, with_info=True)
-        self.assertEqual("GOsa\u00B2", skel.description)
-
     def test_find_reporter_command_with_bindir(self):
         self.config.bindir = "/spam/eggs"
         command = find_reporter_command(self.config)
