@@ -7,13 +7,17 @@ from landscape.client.tests.helpers import LandscapeTest
 
 
 class LockFileTest(LandscapeTest):
-
     def test_read_process_name(self):
-        app = self.makeFile(textwrap.dedent("""\
+        app = self.makeFile(
+            textwrap.dedent(
+                """\
             #!/usr/bin/python3
             import time
             time.sleep(10)
-        """), basename="my_fancy_app")
+        """,
+            ),
+            basename="my_fancy_app",
+        )
         os.chmod(app, 0o755)
         call = subprocess.Popen([app])
         self.addCleanup(call.terminate)
