@@ -25,12 +25,14 @@ from twisted.internet.defer import succeed
 from twisted.internet.error import ProcessExitedAlready
 from twisted.internet.protocol import ProcessProtocol
 
+from landscape.client import GROUP
 from landscape.client import IS_SNAP
 from landscape.client import USER
 from landscape.client.broker.amp import RemoteBrokerConnector
 from landscape.client.broker.amp import RemoteManagerConnector
 from landscape.client.broker.amp import RemoteMonitorConnector
 from landscape.client.deployment import Configuration
+from landscape.client.deployment import convert_arg_to_bool
 from landscape.client.deployment import init_logging
 from landscape.client.reactor import LandscapeReactor
 from landscape.lib.bootstrap import BootstrapDirectory
@@ -508,19 +510,22 @@ class WatchDog:
 class WatchDogConfiguration(Configuration):
     def make_parser(self):
         parser = super().make_parser()
-        parser.add_option(
+        parser.add_argument(
             "--daemon",
             action="store_true",
             help="Fork and run in the background.",
         )
-        parser.add_option(
+        parser.add_argument(
             "--pid-file",
-            type="str",
+            type=str,
             help="The file to write the PID to.",
         )
-        parser.add_option(
+        parser.add_argument(
             "--monitor-only",
-            action="store_true",
+            type=convert_arg_to_bool,
+            nargs="?",
+            const=True,
+            default=False,
             help="Don't enable management features. This is "
             "useful if you want to run the client as a non-root "
             "user.",
@@ -651,26 +656,26 @@ class WatchDogService(Service):
 
 bootstrap_list = BootstrapList(
     [
-        BootstrapDirectory("$data_path", USER, "root", 0o755),
-        BootstrapDirectory("$data_path/package", USER, "root", 0o755),
-        BootstrapDirectory("$data_path/package/hash-id", USER, "root", 0o755),
-        BootstrapDirectory("$data_path/package/binaries", USER, "root", 0o755),
+        BootstrapDirectory("$data_path", USER, GROUP, 0o755),
+        BootstrapDirectory("$data_path/package", USER, GROUP, 0o755),
+        BootstrapDirectory("$data_path/package/hash-id", USER, GROUP, 0o755),
+        BootstrapDirectory("$data_path/package/binaries", USER, GROUP, 0o755),
         BootstrapDirectory(
             "$data_path/package/upgrade-tool",
             USER,
             "root",
             0o755,
         ),
-        BootstrapDirectory("$data_path/messages", USER, "root", 0o755),
-        BootstrapDirectory("$data_path/sockets", USER, "root", 0o750),
+        BootstrapDirectory("$data_path/messages", USER, GROUP, 0o755),
+        BootstrapDirectory("$data_path/sockets", USER, GROUP, 0o750),
         BootstrapDirectory(
             "$data_path/custom-graph-scripts",
             USER,
-            "root",
+            GROUP,
             0o755,
         ),
-        BootstrapDirectory("$log_dir", USER, "root", 0o755),
-        BootstrapFile("$data_path/package/database", USER, "root", 0o644),
+        BootstrapDirectory("$log_dir", USER, GROUP, 0o755),
+        BootstrapFile("$data_path/package/database", USER, GROUP, 0o644),
     ],
 )
 
