@@ -7,11 +7,11 @@ from landscape.lib.warning import hide_warnings
 
 class WarningTest(TestCase):
     def setUp(self):
-        super(WarningTest, self).setUp()
+        super().setUp()
         self.orig_filters = warnings.filters[:]
 
     def tearDown(self):
-        super(WarningTest, self).tearDown()
+        super().tearDown()
         warnings.filters[:] = self.orig_filters
 
     def test_hide_warnings(self):
@@ -24,7 +24,10 @@ class WarningTest(TestCase):
         self.assertEqual(
             filters,
             # The frontmost should "default" (i.e.  print) on UserWarnings
-            [("default", None, UserWarning, None, 0),
-             # The one just behind that should indicate that we should ignore
-             # all other warnings.
-             ("ignore", None, Warning, None, 0)])
+            [
+                ("default", None, UserWarning, None, 0),
+                # The one just behind that should indicate that we should
+                # ignore all other warnings.
+                ("ignore", None, Warning, None, 0),
+            ],
+        )
