@@ -3,8 +3,7 @@ from twisted.internet.defer import succeed
 from landscape.lib.sysstats import MemoryStats
 
 
-class Memory(object):
-
+class Memory:
     def __init__(self, filename="/proc/meminfo"):
         self._filename = filename
 
@@ -13,8 +12,12 @@ class Memory(object):
 
     def run(self):
         memstats = MemoryStats(self._filename)
-        self._sysinfo.add_header("Memory usage", "%d%%" %
-                                 memstats.used_memory_percentage)
-        self._sysinfo.add_header("Swap usage", "%d%%" %
-                                 memstats.used_swap_percentage)
+        self._sysinfo.add_header(
+            "Memory usage",
+            f"{int(memstats.used_memory_percentage):d}%",
+        )
+        self._sysinfo.add_header(
+            "Swap usage",
+            f"{int(memstats.used_swap_percentage):d}%",
+        )
         return succeed(None)
